@@ -1,8 +1,8 @@
 import pandas as pd
+from typing import Union
 from datetime import datetime
 from sqlalchemy.engine import Engine
 from sqlalchemy.sql import select
-from sqlalchemy.exc import OperationalError
 from aiobreaker import CircuitBreaker
 
 from driftage.db.schema import table
@@ -14,6 +14,7 @@ class Connection:
             self,
             db_engine: Engine,
             bulk_size: int,
+            bulk_time: Union[int, float],
             circuit_breaker: CircuitBreaker = CircuitBreaker()):
         """Connects with SQLAlchemy Engine to store and query for
         data for concept drift datection.
@@ -23,6 +24,10 @@ class Connection:
         :param bulk_size: Quantity of data that connection will
             wait to make bulk insert
         :type bulk_size: int
+        :param bulk_time: Time in seconds between last insert and now.
+            If bulk_size is not reached in bulk_time interval,
+            them a insert was done
+        :type bulk_time: Union[int, float]
         :param circuit_breaker: Circuit Breaker configuration to
             connect with Database, defaults to CircuitBreaker()
         :type circuit_breaker: CircuitBreaker, optional
@@ -30,6 +35,8 @@ class Connection:
         self._jid = None
         self._conn = db_engine
         self._bulk_size = bulk_size
+        self._bulk_time = bulk_time
+        self._last_insert_time = datetime.utcnow()
         self._bulk_df = pd.DataFrame()
         self.get_between = circuit_breaker(self.get_between)
         self._insert = circuit_breaker(self._insert)
@@ -54,9 +61,12 @@ class Connection:
         :param df: Data to be inserted
         :type df: pd.DataFrame
         """
+        now = datetime.utcnow()
         self._bulk_df = pd.concat([self._bulk_df, df])
-        if (len(self._bulk_df.index) >= self._bulk_size):
+        if ((len(self._bulk_df.index) >= self._bulk_size) or
+                ((now - self._last_insert_time).seconds > self._bulk_time)):
             await self._insert()
+            self._last_insert_time = now
 
     async def get_between(
             self,
@@ -72,18 +82,19 @@ class Connection:
         :rtype: pd.DataFrame
         """
         selectable = select([table]).where(
-            (table.c.driftage_datetime > from_datetime) &
-            (table.c.driftage_datetime < to_datetime)
+            (table.c.driftage_datetime > str(from_datetime)) &
+            (table.c.driftage_datetime < str(to_datetime))
         )
-        query = str(selectable.compile(self._conn))
+        select_obj = selectable.compile(self._conn,
+                                        compile_kwargs={"literal_binds": True})
+        query = str(select_obj)
         try:
             return pd.read_sql_query(
                 sql=query,
                 con=self._conn,
-                parse_dates=[table.c.driftage_datetime.name],
-                params=[from_datetime, to_datetime]
+                parse_dates=[table.c.driftage_datetime.name]
             )
             self._logger.debug(f"Query executed: {query}")
-        except (OperationalError, KeyError) as e:
+        except Exception as e:
             self._logger.exception(e)
             return pd.DataFrame()
